@@ -83,6 +83,7 @@ typedef struct {
 
 	guint prev_x, prev_y;
 	EelDRect prev_rect;
+	int last_adj_x;
 	int last_adj_y;
 } NautilusIconRubberbandInfo;
 
@@ -170,6 +171,7 @@ struct NautilusIconContainerDetails {
 
 	gboolean icon_selected_on_button_down;
 	NautilusIcon *double_click_icon[2]; /* Both clicks in a double click need to be on the same icon */
+	guint double_click_button[2];
 
 	NautilusIcon *range_selection_base_icon;
 	
@@ -212,10 +214,7 @@ struct NautilusIconContainerDetails {
 	GdkColor label_colors [LAST_LABEL_COLOR];
 	
 	/* State used so arrow keys don't wander if icons aren't lined up.
-	 * Keeps track of last axis arrow key was used on.
 	 */
-	Axis arrow_key_axis;
-	int arrow_key_start;
 	int arrow_key_start_x;
 	int arrow_key_start_y;
 	GtkDirectionType arrow_key_direction;
@@ -271,7 +270,11 @@ struct NautilusIconContainerDetails {
 	guint a11y_item_action_idle_handler;
 	GQueue* a11y_item_action_queue;
 
-	eel_boolean_bit is_reloading : 1;
+	eel_boolean_bit is_loading : 1;
+
+	eel_boolean_bit store_layout_timestamps : 1;
+	eel_boolean_bit store_layout_timestamps_when_finishing_new_icons : 1;
+	time_t layout_timestamp;
 
 	/* interactive search */
 	gboolean disable_popdown;
