@@ -298,9 +298,10 @@ nautilus_link_local_get_additional_text (const char *path)
 static char *
 nautilus_link_get_link_uri_from_desktop (GnomeDesktopItem *desktop_file)
 {
-	const char *launch_string;
+	GFile *file, *parent;
 	const char *type;
 	char *retval;
+	char *scheme;
 
 	retval = NULL;
 
@@ -309,15 +310,7 @@ nautilus_link_get_link_uri_from_desktop (GnomeDesktopItem *desktop_file)
 		return NULL;
 	}
 
-	if (strcmp (type, "Application") == 0) {
-		launch_string = gnome_desktop_item_get_string (desktop_file, "Exec");
-		if (launch_string == NULL) {
-			return NULL;
-		}
-
-		launch_string = gnome_desktop_item_get_location (desktop_file);
-		retval = g_strconcat (NAUTILUS_DESKTOP_COMMAND_SPECIFIER, launch_string, NULL);
-	} else if (strcmp (type, "URL") == 0) {
+	if (strcmp (type, "URL") == 0) {
 		/* Some old broken desktop files use this nonstandard feature, we need handle it though */
 		retval = g_strdup (gnome_desktop_item_get_string (desktop_file, "Exec"));
 	} else if ((strcmp (type, NAUTILUS_LINK_GENERIC_TAG) == 0) ||
@@ -327,6 +320,28 @@ nautilus_link_get_link_uri_from_desktop (GnomeDesktopItem *desktop_file)
 		retval = g_strdup (gnome_desktop_item_get_string (desktop_file, "URL"));
 	}
 
+	if (retval != NULL) {
+		/* Handle local file names.
+		 * Ideally, we'd be able to use
+		 * g_file_parse_name(), but it does not know how to resolve
+		 * relative file names, since the base directory is unknown.
+		 */
+		scheme = g_uri_parse_scheme (retval);
+		if (scheme == NULL) {
+			file = g_file_new_for_uri (gnome_desktop_item_get_location (desktop_file));
+			parent = g_file_get_parent (file);
+			g_object_unref (file);
+
+			if (parent != NULL) {
+				file = g_file_resolve_relative_path (parent, retval);
+				g_free (retval);
+				retval = g_file_get_uri (file);
+				g_object_unref (file);
+				g_object_unref (parent);
+			}
+		}
+	}
+
 	return retval;
 }
 
@@ -339,7 +354,7 @@ nautilus_link_get_link_name_from_desktop (GnomeDesktopItem *desktop_file)
 static char *
 nautilus_link_get_link_icon_from_desktop (GnomeDesktopItem *desktop_file)
 {
-	char *icon_uri;
+	char *icon_uri, *icon_copy, *p;
 	const char *icon;
 	GnomeDesktopItemType desktop_type;
 
@@ -350,7 +365,22 @@ nautilus_link_get_link_icon_from_desktop (GnomeDesktopItem *desktop_file)
 
 	icon = gnome_desktop_item_get_string (desktop_file, GNOME_DESKTOP_ITEM_ICON);
 	if (icon != NULL) {
-		return g_strdup (icon);
+		icon_copy = g_strdup (icon);
+		if (!g_path_is_absolute (icon_copy)) {
+			/* Strip out any extension on non-filename icons. Old desktop files may have this */
+			p = strchr (icon_copy, '.');
+                        /* Only strip known icon extensions */
+			if ((p != NULL) &&
+                         ((g_ascii_strcasecmp (p, ".png") == 0)
+                       || (g_ascii_strcasecmp (p, ".svn") == 0)
+                       || (g_ascii_strcasecmp (p, ".jpg") == 0)
+                       || (g_ascii_strcasecmp (p, ".xpm") == 0)
+                       || (g_ascii_strcasecmp (p, ".bmp") == 0)
+                       || (g_ascii_strcasecmp (p, ".jpeg") == 0))) {
+				*p = 0;
+			}
+		}
+		return icon_copy;
 	}
 
 	desktop_type = gnome_desktop_item_get_entry_type (desktop_file);
@@ -403,11 +433,14 @@ nautilus_link_local_get_link_uri (const char *uri)
 void
 nautilus_link_get_link_info_given_file_contents (const char  *file_contents,
 						 int          link_file_size,
+						 const char  *file_uri,
 						 char       **uri,
 						 char       **name,
-						 char       **icon)
+						 char       **icon,
+						 gboolean    *is_launcher)
 {
 	GnomeDesktopItem *desktop_file;
+	const char *type;
 
 	if (!is_link_data (file_contents, link_file_size)) {
 		return;
@@ -418,10 +451,20 @@ nautilus_link_get_link_info_given_file_contents (const char  *file_contents,
 		return; 
 	}
 
+	gnome_desktop_item_set_location (desktop_file, file_uri);
+
 	*uri = nautilus_link_get_link_uri_from_desktop (desktop_file);
 	*name = nautilus_link_get_link_name_from_desktop (desktop_file);
 	*icon = nautilus_link_get_link_icon_from_desktop (desktop_file);
 
+	*is_launcher = FALSE;
+	type = gnome_desktop_item_get_string (desktop_file, "Type");
+	if (type != NULL &&
+	    strcmp (type, "Application") == 0 &&
+	    gnome_desktop_item_get_string (desktop_file, "Exec") != NULL) {
+		*is_launcher = TRUE;
+	}
+	
 	gnome_desktop_item_unref (desktop_file);
 }
 
