@@ -50,6 +50,7 @@ typedef struct _NautilusNavigationWindow        NautilusNavigationWindow;
 typedef struct _NautilusNavigationWindowClass   NautilusNavigationWindowClass;
 typedef struct _NautilusNavigationWindowDetails NautilusNavigationWindowDetails; 
 
+
 struct _NautilusNavigationWindow {
         NautilusWindow parent_object;
         
@@ -61,12 +62,8 @@ struct _NautilusNavigationWindow {
         GtkWidget *navigation_bar;
 	GtkWidget *path_bar;
         GtkWidget *search_bar;
-       
-        /* Back/Forward chain, and history list. 
-         * The data in these lists are NautilusBookmark pointers. 
-         */
-        GList *back_list, *forward_list;
-        
+	GtkWidget *notebook;
+
         /* Current views stuff */
         GList *sidebar_panels;
         
@@ -115,7 +112,8 @@ void     nautilus_navigation_window_show_status_bar      (NautilusNavigationWind
 gboolean nautilus_navigation_window_status_bar_showing   (NautilusNavigationWindow *window);
 void     nautilus_navigation_window_back_or_forward      (NautilusNavigationWindow *window,
                                                           gboolean                  back,
-                                                          guint                     distance);
+                                                          guint                     distance,
+							  gboolean                  new_tab);
 void     nautilus_navigation_window_show_search          (NautilusNavigationWindow *window);
 
 #endif
