@@ -618,7 +618,9 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
         if ((!do_load_location) ||
 	    (target_window == window && target_slot == slot &&
 	     old_location && g_file_equal (old_location, location))) {
-		g_object_unref (old_location);
+		if (old_location) {
+			g_object_unref (old_location);
+		}
                 return;
         }
 	
@@ -2018,28 +2020,6 @@ nautilus_window_slot_set_content_view (NautilusWindowSlot *slot,
         create_content_view (slot, id);
 }
 
-void
-nautilus_window_manage_views_destroy (NautilusWindow *window)
-{
-	NautilusWindowSlot *slot;
-	GList *l;
-
-	/* Disconnect view signals here so they don't trigger when
-	 * views are destroyed.
-         */
-
-	for (l = window->details->slots; l != NULL; l = l->next) {
-		slot = l->data;
-
-		if (slot->content_view != NULL) {
-			nautilus_window_slot_disconnect_content_view (slot, slot->content_view);
-		}
-		if (slot->new_content_view != NULL) {
-			nautilus_window_slot_disconnect_content_view (slot, slot->new_content_view);
-		}
-	}
-}
-
 void
 nautilus_window_manage_views_close_slot (NautilusWindow *window,
 					 NautilusWindowSlot *slot)
