@@ -36,11 +36,7 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-gtk-extensions.h>
-#include <gtk/gtkaccessible.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkradiomenuitem.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkbindings.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnome/gnome-macros.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -93,9 +89,9 @@ static const int nautilus_zoom_control_accessible_action_signals[] = {
 };
 
 static const char * const nautilus_zoom_control_accessible_action_descriptions[] = {
-	N_("Show the contents in more detail"),
-	N_("Show the contents in less detail"),
-	N_("Show in the default detail level"),
+	N_("Increase the view size"),
+	N_("Decrease the view size"),
+	N_("Use the normal view size")
 };
 
 static GtkMenu *create_zoom_menu (NautilusZoomControl *zoom_control);
@@ -296,6 +292,8 @@ nautilus_zoom_control_instance_init (NautilusZoomControl *zoom_control)
 	gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_out), FALSE);
 	gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_out),
 			       GTK_RELIEF_NONE);
+	gtk_widget_set_tooltip_text (zoom_control->details->zoom_out,
+				     _("Decrease the view size"));
 	g_signal_connect (G_OBJECT (zoom_control->details->zoom_out),
 			  "clicked", G_CALLBACK (zoom_out_clicked),
 			  zoom_control);
@@ -307,6 +305,8 @@ nautilus_zoom_control_instance_init (NautilusZoomControl *zoom_control)
 	gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_button), FALSE);
 	gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_button),
 			       GTK_RELIEF_NONE);
+	gtk_widget_set_tooltip_text (zoom_control->details->zoom_button,
+				     _("Use the normal view size"));
 			       
 	gtk_widget_add_events (GTK_WIDGET (zoom_control->details->zoom_button),
 			       GDK_BUTTON_PRESS_MASK
@@ -343,6 +343,8 @@ nautilus_zoom_control_instance_init (NautilusZoomControl *zoom_control)
 	gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_in), FALSE);
 	gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_in),
 			       GTK_RELIEF_NONE);
+	gtk_widget_set_tooltip_text (zoom_control->details->zoom_in,
+				     _("Increase the view size"));
 	g_signal_connect (G_OBJECT (zoom_control->details->zoom_in),
 			  "clicked", G_CALLBACK (zoom_in_clicked),
 			  zoom_control);
@@ -374,7 +376,7 @@ nautilus_zoom_control_redraw (NautilusZoomControl *zoom_control)
 	gtk_widget_set_sensitive (zoom_control->details->zoom_out,
 				  nautilus_zoom_control_can_zoom_out (zoom_control));
 
-	percent = floor ((100.0 * nautilus_get_relative_icon_size_for_zoom_level (zoom_control->details->zoom_level)) + .5);
+	percent = floor ((100.0 * nautilus_get_relative_icon_size_for_zoom_level (zoom_control->details->zoom_level)) + .2);
 	num_str = g_strdup_printf ("%d%%", percent);
 	gtk_label_set_text (GTK_LABEL (zoom_control->details->zoom_label), num_str);
 	g_free (num_str);
